|pypi| |actions| |coverage|

edc-form-describer
------------------

Describe edc forms in markdown

.. |pypi| image:: https://img.shields.io/pypi/v/edc-form-describer.svg
    :target: https://pypi.python.org/pypi/edc-form-describer

.. |actions| image:: https://github.com/clinicedc/edc-form-describer/workflows/build/badge.svg?branch=develop
  :target: https://github.com/clinicedc/edc-form-describer/actions?query=workflow:build

.. |coverage| image:: https://coveralls.io/repos/github/clinicedc/edc-form-describer/badge.svg?branch=develop
    :target: https://coveralls.io/github/clinicedc/edc-form-describer?branch=develop
